@@ -1,7 +1,22 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 from .api_client import get_data, Paginator
 from .utilities import list_to_filter
-from typing import Union, Optional, Literal
+from typing import Union, Optional
+from typing_extensions import Literal
 from pandas import DataFrame, Series, to_datetime  # type: ignore
 from requests import Response
 from enum import Enum
@@ -141,14 +156,14 @@ class EnergyPriceForecast:
         Examples
         --------
         **Simple**
-        >>> EnergyPriceForecast().get_prices_shortterm(symbol="PCAAS00", group="Crude")
+        >>> ci.EnergyPriceForecast().get_prices_shortterm(symbol="PCAAS00", group="Crude")
 
         **Using Lists**
-        >>> EnergyPriceForecast().get_prices_shortterm(month=[10, 11, 12], group="Crude", delivery_region="United States")
+        >>> ci.EnergyPriceForecast().get_prices_shortterm(month=[10, 11, 12], group="Crude", delivery_region="United States")
 
         **Using Series**
-        >>> groups = EnergyPriceForecast().get_reference_data(type=EnergyPriceForecast.RefTypes.SectorGroups)
-        >>> EnergyPriceForecast().get_prices_shortterm(group=groups['groupName'].tail(2))
+        >>> groups = ci.EnergyPriceForecast().get_reference_data(type=ci.EnergyPriceForecast.RefTypes.SectorGroups)
+        >>> ci.EnergyPriceForecast().get_prices_shortterm(group=groups['groupName'].tail(2))
         """
         path = "prices-short-term"
         filter_params: list[str] = []
@@ -177,8 +192,8 @@ class EnergyPriceForecast:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {"filter": filter_exp, "page": page, "pageSize": page_size}
         return get_data(
@@ -265,14 +280,14 @@ class EnergyPriceForecast:
         Examples
         --------
         **Simple**
-        >>> EnergyPriceForecast().get_prices_longterm(year=2040)
+        >>> ci.EnergyPriceForecast().get_prices_longterm(year=2040)
 
         **Using Lists**
-        >>> EnergyPriceForecast().get_prices_longterm(group=["Crude", "Common Crude Spreads"], delivery_region="United States")
+        >>> ci.EnergyPriceForecast().get_prices_longterm(group=["Crude", "Common Crude Spreads"], delivery_region="United States")
 
         **Using Series**
-        >>> years = EnergyPriceForecast().get_reference_data(type=EnergyPriceForecast.RefTypes.LTYears)
-        >>> EnergyPriceForecast().get_prices_longterm(year=years['year'][:2])
+        >>> years = ci.EnergyPriceForecast().get_reference_data(type=ci.EnergyPriceForecast.RefTypes.LTYears)
+        >>> ci.EnergyPriceForecast().get_prices_longterm(year=years['year'][:2])
         """
         path = "prices-long-term"
         filter_params: list[str] = []
@@ -300,8 +315,8 @@ class EnergyPriceForecast:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {"filter": filter_exp, "page": page, "pageSize": page_size}
         return get_data(
@@ -400,16 +415,16 @@ class EnergyPriceForecast:
         --------
         **Simple**
         >>> from datetime import date
-        >>> EnergyPriceForecast().get_prices_shortterm_archive(modified_date=date(2020, 11, 1), category_id=1, year=2022)
+        >>> ci.EnergyPriceForecast().get_prices_shortterm_archive(modified_date=date(2020, 11, 1), category_id=1, year=2022)
 
         **Using Lists**
         >>> from datetime import date
-        >>> EnergyPriceForecast().get_prices_shortterm_archive(modified_date=date(2020, 11, 1) category_id=1, year=2022, group=["Refinery Margins", "U.S. West Coast"])
+        >>> ci.EnergyPriceForecast().get_prices_shortterm_archive(modified_date=date(2020, 11, 1) category_id=1, year=2022, group=["Refinery Margins", "U.S. West Coast"])
 
         **Using Series**
-        >>> cat_dates = EnergyPriceForecast().get_archive_dates(term_type="short", category="Oil")
+        >>> cat_dates = ci.EnergyPriceForecast().get_archive_dates(term_type="short", category="Oil")
         >>> cat_dates = cat_dates.iloc[0]
-        >>> EnergyPriceForecast().get_prices_shortterm_archive(modified_date=cat_dates['modifiedDate'], category_id=cat_dates['categoryId'], month=12, delivery_region="Singapore")
+        >>> ci.EnergyPriceForecast().get_prices_shortterm_archive(modified_date=cat_dates['modifiedDate'], category_id=cat_dates['categoryId'], month=12, delivery_region="Singapore")
         """
         path = "prices-short-term-archive"
         filter_params: list[str] = []
@@ -438,8 +453,8 @@ class EnergyPriceForecast:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "filter": filter_exp,
@@ -541,16 +556,16 @@ class EnergyPriceForecast:
         --------
         **Simple**
         >>> from datetime import date
-        >>> EnergyPriceForecast().get_prices_longterm_archive(modified_date=date(2020, 11, 1), category_id=1, year=2022)
+        >>> ci.EnergyPriceForecast().get_prices_longterm_archive(modified_date=date(2020, 11, 1), category_id=1, year=2022)
 
         **Using Lists**
         >>> from datetime import date
-        >>> EnergyPriceForecast().get_prices_longterm_archive(modified_date=date(2020, 11, 1) category_id=1, year=2022, group=["Refinery Margins", "U.S. West Coast"])
+        >>> ci.EnergyPriceForecast().get_prices_longterm_archive(modified_date=date(2020, 11, 1) category_id=1, year=2022, group=["Refinery Margins", "U.S. West Coast"])
 
         **Using Series**
-        >>> cat_dates = EnergyPriceForecast().get_archive_dates(term_type="long", category="Oil")
+        >>> cat_dates = ci.EnergyPriceForecast().get_archive_dates(term_type="long", category="Oil")
         >>> cat_dates = cat_dates.iloc[0]
-        >>> EnergyPriceForecast().get_prices_longterm_archive(modified_date=cat_dates['modifiedDate'], category_id=cat_dates['categoryId'], delivery_region="Singapore")
+        >>> ci.EnergyPriceForecast().get_prices_longterm_archive(modified_date=cat_dates['modifiedDate'], category_id=cat_dates['categoryId'], delivery_region="Singapore")
         """
         path = "prices-long-term-archive"
         filter_params: list[str] = []
@@ -578,8 +593,8 @@ class EnergyPriceForecast:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "filter": filter_exp,
@@ -621,7 +636,7 @@ class EnergyPriceForecast:
         Examples
         --------
         **Simple**
-        >>> EnergyPriceForecast().get_reference_data(type=EnergyPriceForecast.RefTypes.Sectors)
+        >>> ci.EnergyPriceForecast().get_reference_data(type=ci.EnergyPriceForecast.RefTypes.Sectors)
         """
         path = type.value
 
@@ -631,6 +646,7 @@ class EnergyPriceForecast:
             path=f"{self._path}{path}",
             params=params,
             paginate=True,
+            paginate_fn=self._paginate,
             raw=raw,
         )
 
@@ -663,7 +679,7 @@ class EnergyPriceForecast:
         Examples
         --------
         **Simple**
-        >>> EnergyPriceForecast().get_archive_dates(term_type="short", category="Oil")
+        >>> ci.EnergyPriceForecast().get_archive_dates(term_type="short", category="Oil")
         """
         path = f"{term_type}-term-archive-dates"
 
