@@ -1,3 +1,17 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 from spgci.api_client import get_data, Paginator
 from typing import List, Union, Optional
@@ -95,7 +109,7 @@ class EWindowMarketData:
         Examples
         --------
         **Simple**
-        >>> EWindowMarketData().get_markets()
+        >>> ci.EWindowMarketData().get_markets()
         """
         params = {
             "groupBy": "market",
@@ -132,8 +146,8 @@ class EWindowMarketData:
 
         Examples
         --------
-        **Free text search**
-        >>> EWindowMarketData().get_products()
+        **Simple**
+        >>> ci.EWindowMarketData().get_products()
         """
         params = {
             "groupBy": "product, market",
@@ -158,6 +172,8 @@ class EWindowMarketData:
         product: Optional[Union[list[str], "Series[str]", str]] = None,
         hub: Optional[Union[list[str], "Series[str]", str]] = None,
         strip: Optional[Union[list[str], "Series[str]", str]] = None,
+        buyer: Optional[Union[list[str], "Series[str]", str]] = None,
+        seller: Optional[Union[list[str], "Series[str]", str]] = None,
         order_type: Optional[
             Union[list[str], list[OrderType], "Series[str]", str, OrderType]
         ] = None,
@@ -192,6 +208,10 @@ class EWindowMarketData:
             filter by hub, by default None
         strip : Optional[Union[list[str], Series[str], str]], optional
             filter by strip, by default None
+        buyer : Optional[Union[list[str], Series[str], str]], optional
+            filter by buyer, by default None
+        seller : Optional[Union[list[str], Series[str], str]], optional
+            filter by seller, by default None
         order_type : Optional[Union[list[str], list[OrderType], Series[str], str, OrderType]], optional
             filter by order type, by default None
         order_state : Optional[ Union[list[str], list[OrderState], Series[str], str, OrderState] ], optional
@@ -230,12 +250,12 @@ class EWindowMarketData:
         --------
         **Simple**
         >>> today = date.today()
-        >>> EWindowMarketData().get_botes(market=["EU BFOE", "US MidWest"], order_time_gte=today)
+        >>> ci.EWindowMarketData().get_botes(market=["EU BFOE", "US MidWest"], order_time_gte=today)
 
         **Date Range**
         >>> d1 = date(2023, 2, 1)
         >>> d2 = date(2023, 2, 3)
-        >>> EWindowMarketData().get_botes(market=["EU BFOE", "US MidWest"], order_time_gt=d1, order_time_lt=d2)
+        >>> ci.EWindowMarketData().get_botes(market=["EU BFOE", "US MidWest"], order_time_gt=d1, order_time_lt=d2)
         """
         endpoint_path = "ewindowdata"
 
@@ -245,6 +265,8 @@ class EWindowMarketData:
         filter_params.append(list_to_filter("product", product))
         filter_params.append(list_to_filter("hub", hub))
         filter_params.append(list_to_filter("strip", strip))
+        filter_params.append(list_to_filter("buyer", buyer))
+        filter_params.append(list_to_filter("seller", seller))
         filter_params.append(list_to_filter("order_type", order_type))
         filter_params.append(list_to_filter("order_id", order_id))
         filter_params.append(list_to_filter("order_state", order_state))
@@ -264,8 +286,8 @@ class EWindowMarketData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {"page": page, "pageSize": page_size, "filter": filter_exp}
 
