@@ -1,3 +1,17 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from spgci.api_client import Paginator, get_data
 from typing import List, Union, Optional
 from datetime import date
@@ -27,6 +41,7 @@ class ForwardCurves:
     class MatFrequency(Enum):
         """Derivative Maturity Frequency"""
 
+        Hour = "hour"
         Week = "week"
         Month = "month"
         Quarter = "quarter"
@@ -78,9 +93,11 @@ class ForwardCurves:
 
         # make date fields the correct datatype
 
-        if len(df) > 0:
+        if "assessDate" in df.columns:
             df["assessDate"] = to_datetime(df["assessDate"])
+        if "roll_date" in df.columns:
             df["roll_date"] = to_datetime(df["roll_date"])
+        if "expiry_date" in df.columns:
             df["expiry_date"] = to_datetime(df["expiry_date"])
 
         return df
@@ -163,16 +180,16 @@ class ForwardCurves:
         Examples
         --------
         **Get Latest Curve**
-        >>> ForwardCurves().get_assessments(curve_code="CN003")
+        >>> ci.ForwardCurves().get_assessments(curve_code="CN003")
 
         **Get Multiple Curves**
-        >>> ForwardCurves().get_assessments(curve_code=["CN003", "CN002"])
+        >>> ci.ForwardCurves().get_assessments(curve_code=["CN003", "CN002"])
 
         **Get Monthly Contracts**
-        >>> ForwardCurves().get_assessments(curve_code=["CN003", "CN002"], derivative_maturity_frequency="Month")
+        >>> ci.ForwardCurves().get_assessments(curve_code=["CN003", "CN002"], derivative_maturity_frequency="Month")
 
         **Get Assessments for a Curve on a particular date**
-        >>> ForwardCurves().get_assessments(curve_code=["CN003"], assess_date=date(2023,2,13))
+        >>> ci.ForwardCurves().get_assessments(curve_code=["CN003"], assess_date=date(2023,2,13))
         """
         endpoint_path = "curve-codes"
 
@@ -200,8 +217,8 @@ class ForwardCurves:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "filter": filter_exp,
@@ -230,6 +247,7 @@ class ForwardCurves:
         ] = None,
         currency: Optional[Union["list[str]", "Series[str]", str]] = None,
         uom: Optional[Union["list[str]", "Series[str]", str]] = None,
+        delivery_region: Optional[Union["list[str]", "Series[str]", str]] = None,
         curve_code: Optional[Union["list[str]", "Series[str]", str]] = None,
         curve_type: Optional[
             Union["list[str]", "list[CurveType]", "Series[str]", str, CurveType]
@@ -262,6 +280,8 @@ class ForwardCurves:
              filter by currency, by default None
          uom : Optional[Union[list[str], Series[str], str]], optional
              filter by unit of measure, by default None
+         delivery_region : Optional[Union[list[str], Series[str], str]], optional
+             filter by delivery_region, by default None
          curve_code : Optional[Union[list[str], Series[str], str]], optional
              filter by curve code, by default None
          curve_type : Optional[Union[list[str], list[CurveType], Series[str], str, CurveType]], optional
@@ -294,13 +314,13 @@ class ForwardCurves:
          Examples
          --------
          **Free text search**
-         >>> ForwardCurves().get_curves(q="Brent")
+         >>> ci.ForwardCurves().get_curves(q="Brent")
 
          **Find Benzene Curves**
-         >>> ForwardCurves().get_curves(commodity="Benzene")
+         >>> ci.ForwardCurves().get_curves(commodity="Benzene")
 
          **Find Monthly Relative Curves by MDC**
-         >>> ForwardCurves().get_curves(curve_type=CurveType.Relative, mdc=["DR"], derivative_maturity_frequency='Month')
+         >>> ci.ForwardCurves().get_curves(curve_type=ci.ForwardCurves.CurveType.Relative, mdc=["DR"], derivative_maturity_frequency='Month')
         """
         filter_params: List[str] = []
 
@@ -308,6 +328,7 @@ class ForwardCurves:
         filter_params.append(list_to_filter("contract_type", contract_type))
         filter_params.append(list_to_filter("currency", currency))
         filter_params.append(list_to_filter("uom", uom))
+        filter_params.append(list_to_filter("delivery_region", delivery_region))
         filter_params.append(
             list_to_filter(
                 "derivative_maturity_frequency", derivative_maturity_frequency
@@ -321,8 +342,8 @@ class ForwardCurves:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "q": q,
