@@ -1,6 +1,20 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 from spgci.utilities import list_to_filter
-from spgci.api_client import get_data, Paginator
+from spgci.api_client import get_data, Paginator, _nop_paginate
 from typing import List, Optional, Union
 import pandas as pd
 from pandas import Series
@@ -26,6 +40,7 @@ class MarketData:
 
     _path = "market-data/v3/value/"
     _ref_path = "market-data/reference-data/v3/search"
+    _mdd_fields = "deltaPrice, deltaPercent, pValue, pDate"
 
     class ContractType(Enum):
         """Contract Type"""
@@ -70,8 +85,14 @@ class MarketData:
         df = pd.json_normalize(j["results"], record_path=["data"], meta="symbol")  # type: ignore
 
         if len(df) > 0:
+            df.columns = df.columns.str.replace("change.", "", regex=True)  # type: ignore
+
+        if "assessDate" in df.columns:
             df["assessDate"] = pd.to_datetime(df["assessDate"])  # type: ignore
+        if "modDate" in df.columns:
             df["modDate"] = pd.to_datetime(df["modDate"])  # type: ignore
+        if "pDate" in df.columns:
+            df["pDate"] = pd.to_datetime(df["pDate"])  # type: ignore
 
         return df
 
@@ -151,10 +172,10 @@ class MarketData:
         Examples
         --------
         **Simple**
-        >>> MarketData().get_assessments_symbol_current(symbol="PCAAS00")
+        >>> ci.MarketData().get_assessments_symbol_current(symbol="PCAAS00")
 
         **Multiple Symbols and Bates**
-        >>> MarketData().get_assessments_symbol_current(symbol=["PCAAS00", "PCAAT00"], bate=["c", "h"])
+        >>> ci.MarketData().get_assessments_symbol_current(symbol=["PCAAS00", "PCAAT00"], bate=["c", "h"])
         """
         filter_params: List[str] = []
 
@@ -165,11 +186,16 @@ class MarketData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         endpoint_path = "current/symbol"
-        params = {"filter": filter_exp, "page": page, "pageSize": page_size}
+        params = {
+            "filter": filter_exp,
+            "page": page,
+            "pageSize": page_size,
+            "field": self._mdd_fields,
+        }
 
         return get_data(
             path=f"{self._path}{endpoint_path}",
@@ -255,15 +281,15 @@ class MarketData:
         Examples
         --------
         **Simple**
-        >>> MarketData().get_assessments_symbol_historical(symbol="PCAAS00")
+        >>> ci.MarketData().get_assessments_symbol_historical(symbol="PCAAS00")
 
         **Multiple Symbols and Bates**
-        >>> MarketData().get_assessments_symbol_historical(symbol=["PCAAS00", "PCAAT00"], bate=["c", "h"])
+        >>> ci.MarketData().get_assessments_symbol_historical(symbol=["PCAAS00", "PCAAT00"], bate=["c", "h"])
 
         **Date Range**
         >>> d1 = date(2023, 1, 1)
         >>> d2 = date(2023, 2, 1)
-        >>> MarketData().get_assessments_symbol_historical(symbol=["PCAAS00", "PCAAT00"], assess_date_gte=d1, assess_date_lte=d2])
+        >>> ci.MarketData().get_assessments_symbol_historical(symbol=["PCAAS00", "PCAAT00"], assess_date_gte=d1, assess_date_lte=d2])
         """
         filter_params: List[str] = []
 
@@ -296,8 +322,8 @@ class MarketData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         endpoint_path = "history/symbol"
         params = {"filter": filter_exp, "page": page, "pageSize": page_size}
@@ -355,13 +381,13 @@ class MarketData:
         Examples
         --------
         **Simple**
-        >>> MarketData().get_assessments_by_mdc_current(mdc="ET")
+        >>> ci.MarketData().get_assessments_by_mdc_current(mdc="ET")
 
         **Include bate**
-        >>> MarketData().get_assessments_by_mdc_current(mdc="ET", bate=['c', 'u'])
+        >>> ci.MarketData().get_assessments_by_mdc_current(mdc="ET", bate=['c', 'u'])
 
         **Turn off auto pagination**
-        >>> MarketData().get_assessments_by_mdc_current(mdc="ET", paginate=false)
+        >>> ci.MarketData().get_assessments_by_mdc_current(mdc="ET", paginate=false)
         """
         filter_params: List[str] = []
         filter_params.append(f'MDC: "{mdc}"')
@@ -371,11 +397,16 @@ class MarketData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         endpoint_path = "current/mdc"
-        params = {"filter": filter_exp, "page": page, "pageSize": page_size}
+        params = {
+            "filter": filter_exp,
+            "page": page,
+            "pageSize": page_size,
+            "field": self._mdd_fields,
+        }
         return get_data(
             path=f"{self._path}{endpoint_path}",
             df_fn=self._convert_to_df,
@@ -460,12 +491,12 @@ class MarketData:
         Examples
         --------
         **Simple**
-        >>> MarketData().get_assessments_by_mdc_historical(mdc="ET", assess_date=date(2023,2,1))
+        >>> ci.MarketData().get_assessments_by_mdc_historical(mdc="ET", assess_date=date(2023,2,1))
 
         **Date Range**
         >>> d1 = date(2023,1,1)
         >>> d2 = date(2023,2,1)
-        >>> MarketData().get_assessments_by_mdc_historical(mdc="ET", assess_date_gte=d1, assess_date_lte=d2)
+        >>> ci.MarketData().get_assessments_by_mdc_historical(mdc="ET", assess_date_gte=d1, assess_date_lte=d2)
         """
         filter_params: List[str] = []
         filter_params.append(f'MDC: "{mdc}"')
@@ -497,8 +528,8 @@ class MarketData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         endpoint_path = "history/mdc"
         params = {"filter": filter_exp, "page": page, "pageSize": page_size}
@@ -534,6 +565,11 @@ class MarketData:
                 AssessmentFrequency,
             ]
         ] = None,
+        modified_date: Optional[date] = None,
+        modified_date_lt: Optional[date] = None,
+        modified_date_lte: Optional[date] = None,
+        modified_date_gt: Optional[date] = None,
+        modified_date_gte: Optional[date] = None,
         filter_exp: Optional[str] = None,
         page: int = 1,
         page_size: int = 1000,
@@ -565,6 +601,16 @@ class MarketData:
             filter by Market Data Category, by default None
         assessment_frequency: Optional[Union[list[str], list[AssessmentFrequency], Series[str], str, AssessmentFrequency]], optional
             filter by Assessment Frequency, by default None
+        modified_date : Optional[date], optional
+            filter by ``modified_date = x`` , by default None
+        modified_date_lt: Optional[date], optional
+            filter by ``modified_date < x``, by default None
+        modified_date_lte : Optional[date], optional
+            filter by ``modified_date <= x``, by default None
+        modified_date_gt : Optional[date], optional
+            filter by ``modified_date > x``, by default None
+        modified_date_gte : Optional[date], optional
+            filter by ``modified_date >= x``, by default None
         filter_exp : Optional[str], optional
             pass-thru ``filter`` query param to use a handcrafted filter expression, by default None
         page : int, optional
@@ -586,16 +632,16 @@ class MarketData:
         Examples
         --------
         **Free text search**
-        >>> MarketData().get_symbols(q="Brent")
+        >>> ci.MarketData().get_symbols(q="Brent")
 
         **Using String**
-        >>> MarketData().get_symbols(contract_type="Forward")
+        >>> ci.MarketData().get_symbols(contract_type="Forward")
 
         **Using List**
-        >>> MarketData().get_symbols(currency=["USD", "EUR"])
+        >>> ci.MarketData().get_symbols(currency=["USD", "EUR"])
 
         **Using Enum**
-        >>> MarketData().get_symbols(currency=["USD", "EUR"], contract_type=[MarketData.ContractType.Forward, MarketData.ContractType.Spot])
+        >>> ci.MarketData().get_symbols(currency=["USD", "EUR"], contract_type=[ci.MarketData.ContractType.Forward, ci.MarketData.ContractType.Spot])
         """
         filter_params: List[str] = []
 
@@ -612,13 +658,23 @@ class MarketData:
         filter_params.append(
             list_to_filter("assessment_frequency", assessment_frequency)
         )
+        if modified_date != None:
+            filter_params.append(f'modified_date: "{modified_date}"')
+        if modified_date_gt != None:
+            filter_params.append(f'modified_date > "{modified_date_gt}"')
+        if modified_date_gte != None:
+            filter_params.append(f'modified_date >= "{modified_date_gte}"')
+        if modified_date_lt != None:
+            filter_params.append(f'modified_date < "{modified_date_lt}"')
+        if modified_date_lte != None:
+            filter_params.append(f'modified_date <= "{modified_date_lte}"')
 
         filter_params = [fp for fp in filter_params if fp != ""]
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "q": q,
@@ -659,5 +715,8 @@ class MarketData:
         params = {"subscribed_only": subscribed_only}
 
         return get_data(
-            path="market-data/reference-data/v3/mdc", params=params, raw=raw
+            path="market-data/reference-data/v3/mdc",
+            params=params,
+            raw=raw,
+            paginate_fn=_nop_paginate,
         )
