@@ -1,3 +1,17 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 from requests import Response
 from pandas import DataFrame, Series
@@ -132,14 +146,14 @@ class WorldOilSupply:
         Examples
         --------
         **Get Production Costs**
-        >>> WorldOilSupply().get_cost_of_supplies(cost_of_supplies_type="Production")
+        >>> ci.WorldOilSupply().get_cost_of_supplies(cost_of_supplies_type="Production")
 
         **Get Crude supplies costs in Albania**
-        >>> WorldOilSupply().get_cost_of_supplies(supply_type="Crude", country="Albania")
+        >>> ci.WorldOilSupply().get_cost_of_supplies(supply_type="Crude", country="Albania")
 
         **Compose Ref Data with Costs**
-        >>> sup_sub_types = WorldOilSupply().get_reference_data(type=WorldOilSupply.RefType.SupplySubTypes)
-        >>> WorldOilSupply().get_cost_of_supplies(supply_subtype=sup_sub_types['supplySubTypeName'][:2])
+        >>> sup_sub_types = ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply.RefTypes.SupplySubTypes)
+        >>> ci.WorldOilSupply().get_cost_of_supplies(supply_subtype=sup_sub_types['supplySubTypeName'][:2])
         """
         endpoint_path = "cost-of-supplies"
 
@@ -165,8 +179,8 @@ class WorldOilSupply:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_param)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_param)
+        elif len(filter_param) > 0:
+            filter_exp = " AND ".join(filter_param) + " AND (" + filter_exp + ")"
 
         params = {
             "pageSize": page_size,
@@ -185,6 +199,10 @@ class WorldOilSupply:
         self,
         *,
         year: Optional[Union[int, list[int], "Series[int]"]] = None,
+        year_gt: Optional[int] = None,
+        year_gte: Optional[int] = None,
+        year_lt: Optional[int] = None,
+        year_lte: Optional[int] = None,
         region: Optional[Union[str, list[str], "Series[str]"]] = None,
         country: Optional[Union[str, list[str], "Series[str]"]] = None,
         state: Optional[Union[str, list[str], "Series[str]"]] = None,
@@ -213,6 +231,14 @@ class WorldOilSupply:
         ----------
         year : Optional[Union[int, list[int], Series[int]]], optional
             filter by year, by default None
+        year_gt : Optional[int], optional
+            filter by ``year > x``, by default None
+        year_gte : Optional[int], optional
+            filter by ``year >= x``, by default None
+        year_lt : Optional[int], optional
+            filter by ``year < x``, by default None
+        year_lte : Optional[int], optional
+            filter by ``year <= x``, by default None
         region : Optional[Union[str, list[str], Series[str]]], optional
             filter by region, by default None
         country : Optional[Union[str, list[str], Series[str]]], optional
@@ -264,14 +290,14 @@ class WorldOilSupply:
         Examples
         --------
         **Get Ownership by Company**
-        >>> WorldOilSupply().get_ownership(company="ADNOC")
+        >>> ci.WorldOilSupply().get_ownership(company="ADNOC")
 
         **Get Ownership by state companies in the Middle East, Africa, in 2040**
-        >>> WorldOilSupply().get_ownership(company_type="State", year=2040, region=["Middle East", "Africa"])
+        >>> ci.WorldOilSupply().get_ownership(company_type="State", year=2040, region=["Middle East", "Africa"])
 
         **Compose Ref Data with Ownership**
-        >>> res_locations = WorldOilSupply.get_reference_data(type=WorldOilSupply.RefType.ReserveLocations)
-        >>> WorldOilSupply().get_ownership(reserve_location=res_locations['reserveLocationName'][:2], country='Norway', year=2031)
+        >>> res_locations = ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply.RefTypes.ReserveLocations)
+        >>> ci.WorldOilSupply().get_ownership(reserve_location=res_locations['reserveLocationName'][:2], country='Norway', year=2031)
         """
         endpoint_path = "ownership"
 
@@ -294,12 +320,21 @@ class WorldOilSupply:
         filter_param.append(list_to_filter("companyTypeName", company_type))
         filter_param.append(list_to_filter("ownershipTypeName", ownership_type))
 
+        if year_gt:
+            filter_param.append(f"year > {year_gt}")
+        if year_gte:
+            filter_param.append(f"year >= {year_gte}")
+        if year_lt:
+            filter_param.append(f"year < {year_lt}")
+        if year_lte:
+            filter_param.append(f"year <= {year_lte}")
+
         filter_param = [fp for fp in filter_param if fp != ""]
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_param)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_param)
+        elif len(filter_param) > 0:
+            filter_exp = " AND ".join(filter_param) + " AND (" + filter_exp + ")"
 
         params = {
             "pageSize": page_size,
@@ -319,6 +354,10 @@ class WorldOilSupply:
         *,
         scenario_term_id: int = 2,
         year: Optional[Union[int, list[int], "Series[int]"]] = None,
+        year_gt: Optional[int] = None,
+        year_gte: Optional[int] = None,
+        year_lt: Optional[int] = None,
+        year_lte: Optional[int] = None,
         month: Optional[Union[int, list[int], "Series[int]"]] = None,
         region: Optional[Union[str, list[str], "Series[str]"]] = None,
         country: Optional[Union[str, list[str], "Series[str]"]] = None,
@@ -347,6 +386,14 @@ class WorldOilSupply:
             long-term (2) or short-term forecasts (1), by default 2
         year : Optional[Union[str, list[int], Series[int]]], optional
             filter by year, by default None
+        year_gt : Optional[int], optional
+            filter by ``year > x``, by default None
+        year_gte : Optional[int], optional
+            filter by ``year >= x``, by default None
+        year_lt : Optional[int], optional
+            filter by ``year < x``, by default None
+        year_lte : Optional[int], optional
+            filter by ``year <= x``, by default None
         month : Optional[Union[str, list[int], Series[int]]], optional
             filter by month, by default None
         region : Optional[Union[str, list[str], Series[str]]], optional
@@ -394,16 +441,16 @@ class WorldOilSupply:
         Examples
         --------
         **Get Production by Country**
-        >>> WorldOilSupply().get_production(scenario_term_id=1, country="Qatar", year=2050)
+        >>> ci.WorldOilSupply().get_production(scenario_term_id=1, country="Qatar", year=2050)
 
         **Get Production of Crude in Middle East, Africa, in 2024**
-        >>> WorldOilSupply().get_production(year=2024, region=["Middle East", "Africa"], production_element="Crude")
+        >>> ci.WorldOilSupply().get_production(year=2024, region=["Middle East", "Africa"], production_element="Crude")
 
         **Compose Ref Data with Production**
-        >>> opec = WorldOilSupply().get_reference_data(type=WorldOilSupply().RefType.OPECCountries)
+        >>> opec = ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply().RefTypes.OPECCountries)
         >>> filt = opec['effectiveLeaveDate'].isna()
         >>> opec = opec[filt]
-        >>> WorldOilSupply().get_production(country=opec['countryName'][3:], production_type="Production", year=2024)
+        >>> ci.WorldOilSupply().get_production(country=opec['countryName'][3:], production_type="Production", year=2024)
         """
         endpoint_path = "production"
 
@@ -424,12 +471,21 @@ class WorldOilSupply:
         filter_param.append(list_to_filter("productionElementName", production_element))
         filter_param.append(list_to_filter("gradeElementName", grade_element))
 
+        if year_gt:
+            filter_param.append(f"year > {year_gt}")
+        if year_gte:
+            filter_param.append(f"year >= {year_gte}")
+        if year_lt:
+            filter_param.append(f"year < {year_lt}")
+        if year_lte:
+            filter_param.append(f"year <= {year_lte}")
+
         filter_param = [fp for fp in filter_param if fp != ""]
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_param)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_param)
+        elif len(filter_param) > 0:
+            filter_exp = " AND ".join(filter_param) + " AND (" + filter_exp + ")"
 
         params = {
             "scenarioTermId": scenario_term_id,
@@ -531,15 +587,15 @@ class WorldOilSupply:
         Examples
         --------
         **Get Production Archive by Country**
-        >>> WorldOilSupply().get_production_archive(scenario_id=2243, scenario_term_id=2, country="Qatar", year=2021)
+        >>> ci.WorldOilSupply().get_production_archive(scenario_id=2243, scenario_term_id=2, country="Qatar", year=2021)
 
         **Get List of Scenario IDs**
-        >>> WorldOilSupply().get_reference_data(type=WorldOilSupply().RefType.ScenarioList)
+        >>> ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply.RefTypes.ScenarioList)
 
         **Compose Ref Data with Production Archive**
-        >>> scenarios = WorldOilSupply.get_reference_data(type=WorldOilSupply().RefType.ScenarioList)
+        >>> scenarios = ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply.RefTypes.ScenarioList)
         >>> s_id = scenarios['scenarioId'][1]
-        >>> WorldOilSupply().get_production_archive(scenario_id=s_id, production_type="Capacity", country="Albania")
+        >>> ci.WorldOilSupply().get_production_archive(scenario_id=s_id, production_type="Capacity", country="Albania")
         """
         endpoint_path = "production-archive"
 
@@ -565,8 +621,8 @@ class WorldOilSupply:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_param)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_param)
+        elif len(filter_param) > 0:
+            filter_exp = " AND ".join(filter_param) + " AND (" + filter_exp + ")"
 
         params = {
             "scenarioTermId": scenario_term_id,
@@ -606,7 +662,7 @@ class WorldOilSupply:
         Examples
         --------
         **Simple**
-        >>> WorldOilSupply().get_reference_data(type=WorldOilSupply.RefTypes.Grades)
+        >>> ci.WorldOilSupply().get_reference_data(type=ci.WorldOilSupply.RefTypes.Grades)
         """
         endpoint_path = type.value
 
