@@ -1,3 +1,17 @@
+# Copyright 2025 S&P Global Commodity Insights
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#       http://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import annotations
 from typing import Union, Optional
 from requests import Response
@@ -26,7 +40,7 @@ class WorldRefineryData:
     ``get_margins()`` to get margin data.
     """
 
-    _endpoint = "odata/refinery-data/v2/"
+    _endpoint = "odata/refinery-data/v2.2/"
 
     class RefTypes(Enum):
         """World Refinery Database Reference Data Type"""
@@ -58,6 +72,22 @@ class WorldRefineryData:
 
         return df
 
+    @staticmethod
+    def _ts_to_df(resp: Response) -> DataFrame:
+        j = resp.json()
+        df = json_normalize(j, record_path="value")
+
+        # drop odata artifacts
+        drop = df.columns[df.columns.str.contains("@odata")]
+        df = df[df.columns.drop(drop)]  # type: ignore
+
+        if len(df) > 0 and "start_date" in df.columns:
+            df["start_date"] = to_datetime(df["start_date"], utc=True)  # type: ignore
+        if len(df) > 0 and "end_date" in df.columns:
+            df["end_date"] = to_datetime(df["end_date"], utc=True)  # type: ignore
+
+        return df
+
     @staticmethod
     def _to_df(resp: Response) -> DataFrame:
         j = resp.json()
@@ -167,14 +197,14 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_capacity(year=2008)
+        >>> ci.WorldRefineryData().get_capacity(year=2008)
 
         **Using Lists**
-        >>> WorldRefineryData().get_capacity(year_gte=2022, process_unit=["Atmos Distillation", "Dist Hydrocracking"])
+        >>> ci.WorldRefineryData().get_capacity(year_gte=2022, process_unit=["Atmos Distillation", "Dist Hydrocracking"])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.Refineries)
-        >>> WorldRefineryData().get_capacity(year=2020, refinery_id=df["Id"][:3])
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.Refineries)
+        >>> ci.WorldRefineryData().get_capacity(year=2020, refinery_id=df["Id"][:3])
         """
         endpoint = "capacity"
 
@@ -205,8 +235,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -302,14 +332,14 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_runs(owner="BP")
+        >>> ci.WorldRefineryData().get_runs(owner="BP")
 
         **Using Lists**
-        >>> WorldRefineryData().get_runs(year_gte=2020, refinery_id=[18, 357])
+        >>> ci.WorldRefineryData().get_runs(year_gte=2020, refinery_id=[18, 357])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.ProcessUnits)
-        >>> WorldRefineryData().get_runs(year=2020, process_unit=df["Name"][:-10], refineryId=1)
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.ProcessUnits)
+        >>> ci.WorldRefineryData().get_runs(year=2020, process_unit=df["Name"][:-10], refineryId=1)
         """
         endpoint = "runs"
 
@@ -339,8 +369,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -436,16 +466,16 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_yields(refineryId=1)
+        >>> ci.WorldRefineryData().get_yields(refineryId=1)
 
         **Using Lists**
-        >>> WorldRefineryData().get_yields(year=2020, owner=["BP", "S N Repal"])
+        >>> ci.WorldRefineryData().get_yields(year=2020, owner=["BP", "S N Repal"])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.ProcessUnits)
-        >>> WorldRefineryData().get_yields(year=2020, process_unit=df["Name"][:-10], refineryId=1)
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.ProcessUnits)
+        >>> ci.WorldRefineryData().get_yields(year=2020, process_unit=df["Name"][:-10], refineryId=1)
         """
-        endpoint = "runs"
+        endpoint = "yields"
 
         filter_params: list[str] = []
 
@@ -473,8 +503,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -630,10 +660,10 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_outage_alerts(refineryId=245)
+        >>> ci.WorldRefineryData().get_outage_alerts(refineryId=245)
 
         **Using Lists**
-        >>> WorldRefineryData().get_outage_alerts(process_unit=["Coker", "CDU"])
+        >>> ci.WorldRefineryData().get_outage_alerts(process_unit=["Coker", "CDU"])
         """
         endpoint = "outage-alerts"
 
@@ -680,8 +710,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params: dict[str, Union[str, int]] = {
             "page": page,
@@ -692,13 +722,12 @@ class WorldRefineryData:
             params["filter"] = filter_exp
 
         return get_data(
-            path=f"refinery-data/v1/{endpoint}",
+            path=f"refinery-data/v1.2/{endpoint}",
             params=params,
             paginate=paginate,
             raw=raw,
             df_fn=self._outage_alerts_to_df,
             paginate_fn=self._outage_alert_pg_fn,
-            include_auth_header=False,
         )
 
     def get_outages(
@@ -805,15 +834,15 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_outages(year=2020, quarter=3)
+        >>> ci.WorldRefineryData().get_outages(year=2020, quarter=3)
 
         **Using Lists**
-        >>> WorldRefineryData().get_outages(year=2020, planning_status="Unplanned", process_unit=["Coker", "CDU"])
+        >>> ci.WorldRefineryData().get_outages(year=2020, planning_status="Unplanned", process_unit=["Coker", "CDU"])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.Refineries)
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.Refineries)
         >>> df = df[df['Country.Name'] == "Mexico"]
-        >>> WorldRefineryData().get_outages(outage_vol_gte=200, refinery_id=df['Id'])
+        >>> ci.WorldRefineryData().get_outages(outage_vol_gte=200, refinery_id=df['Id'])
         """
         endpoint = "outages"
 
@@ -862,8 +891,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -907,7 +936,8 @@ class WorldRefineryData:
         paginate: bool = False,
         raw: bool = False,
     ) -> Union[Response, DataFrame]:
-        """_summary_
+        """
+        Fetch refinery ownership
 
         Parameters
         ----------
@@ -952,15 +982,15 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_ownership(owner="BP")
+        >>> ci.WorldRefineryData().get_ownership(owner="BP")
 
         **Using Lists**
-        >>> WorldRefineryData().get_ownership(year_gte=2017, quarter=[3, 4])
+        >>> ci.WorldRefineryData().get_ownership(year_gte=2017, quarter=[3, 4])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.Owners)
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.Owners)
         >>> df = df[df['Name'].str.contains("Shell")]
-        >>> WorldRefineryData().get_ownership(owner=df['Name'])
+        >>> ci.WorldRefineryData().get_ownership(owner=df['Name'])
         """
         endpoint = "ownership"
 
@@ -986,8 +1016,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -1027,7 +1057,8 @@ class WorldRefineryData:
         paginate: bool = False,
         raw: bool = False,
     ) -> Union[Response, DataFrame]:
-        """_summary_
+        """
+        Fetch refinery margins
 
         Parameters
         ----------
@@ -1064,15 +1095,15 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_margins(date=date(2023, 2, 17))
+        >>> ci.WorldRefineryData().get_margins(date=date(2023, 2, 17))
 
         **Using Lists**
-        >>> WorldRefineryData().get_margins(date_gte=date(2023, 1, 1), margin_type=['Dated Brent NWE Cracking', 'Dubai Singapore Cracking'])
+        >>> ci.WorldRefineryData().get_margins(date_gte=date(2023, 1, 1), margin_type=['Dated Brent NWE Cracking', 'Dubai Singapore Cracking'])
 
         **Using Series**
-        >>> df = WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.MarginTypes)
+        >>> df = ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.MarginTypes)
         >>> df = df[df['Name'].str.contains("Brent")]
-        >>> WorldRefineryData().get_ownership(date_gte=date(2023, 1, 1), margin_type=df['Name'])
+        >>> ci.WorldRefineryData().get_ownership(date_gte=date(2023, 1, 1), margin_type=df['Name'])
         """
         endpoint = "margins"
 
@@ -1094,8 +1125,8 @@ class WorldRefineryData:
 
         if filter_exp is None:
             filter_exp = " AND ".join(filter_params)
-        else:
-            filter_exp += " AND " + " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
 
         params = {
             "$skip": skip,
@@ -1143,7 +1174,7 @@ class WorldRefineryData:
         Examples
         --------
         **Simple**
-        >>> WorldRefineryData().get_reference_data(type=WorldRefineryData.RefTypes.Owners)
+        >>> ci.WorldRefineryData().get_reference_data(type=ci.WorldRefineryData.RefTypes.Owners)
         """
         endpoint_path = type.value
 
@@ -1165,3 +1196,186 @@ class WorldRefineryData:
             paginate_fn=self._paginate,
             df_fn=df_fn,
         )
+
+    def get_outages_grouped(
+        self,
+        *,
+        start_date: Optional[Union[date, list[date], "Series[date]"]] = None,
+        start_date_gt: Optional[date] = None,
+        start_date_gte: Optional[date] = None,
+        start_date_lt: Optional[date] = None,
+        start_date_lte: Optional[date] = None,
+        end_date: Optional[Union[date, list[date], "Series[date]"]] = None,
+        end_date_gt: Optional[date] = None,
+        end_date_gte: Optional[date] = None,
+        end_date_lt: Optional[date] = None,
+        end_date_lte: Optional[date] = None,
+        refinery_id: Optional[Union[int, list[int], "Series[int]"]] = None,
+        owner: Optional[Union[str, list[str], "Series[str]"]] = None,
+        process_unit: Optional[Union[str, list[str], "Series[str]"]] = None,
+        planning_status: Optional[Union[str, list[str], "Series[str]"]] = None,
+        outage_id: Optional[Union[int, list[int], "Series[int]"]] = None,
+        outage_vol: Optional[Union[float, list[float], "Series[float]"]] = None,
+        outage_vol_gt: Optional[float] = None,
+        outage_vol_gte: Optional[float] = None,
+        outage_vol_lt: Optional[float] = None,
+        outage_vol_lte: Optional[float] = None,
+        country: Optional[Union[str, list[str], "Series[str]"]] = None,
+        region: Optional[Union[str, list[str], "Series[str]"]] = None,
+        filter_exp: Optional[str] = None,
+        skip: int = 0,
+        page_size: int = 1000,
+        paginate: bool = False,
+        raw: bool = False,
+    ) -> Union[Response, DataFrame]:
+        """
+        Transformation of refinery outages endpoint so that each outage-owner is a single row with outage `start_date` and `end_date` as columns
+
+        Parameters
+        ----------
+        start_date : Optional[Union[date, list[date], Series[date]]], optional
+            filter by ``start_date = x`` , by default None
+        start_date_gt : Optional[date], optional
+            filter by ``start_date > x`` , by default None
+        start_date_gte : Optional[date], optional
+            filter by ``start_date >= x`` , by default None
+        start_date_lt : Optional[date], optional
+            filter by ``start_date < x`` , by default None
+        start_date_lte : Optional[date], optional
+            filter by ``start_date <= x`` , by default None
+        end_date : Optional[Union[date, list[date], Series[date]]], optional
+            filter by ``end_date = x`` , by default None
+        end_date_gt : Optional[date], optional
+            filter by ``end_date > x`` , by default None
+        end_date_gte : Optional[date], optional
+            filter by ``end_date >= x`` , by default None
+        end_date_lt : Optional[date], optional
+            filter by ``end_date < x`` , by default None
+        end_date_lte : Optional[date], optional
+            filter by ``end_date <= x`` , by default None
+        refinery_id : Optional[Union[int, list[int], Series[int]]], optional
+            filter by refineryId, by default None
+        owner : Optional[Union[str, list[str], Series[str]]], optional
+            filter by Owner/Name, by default None
+        process_unit : Optional[Union[str, list[str], Series[str]]], optional
+            filter by ProcessUnit/Name, by default None
+        planning_status : Optional[Union[str, list[str], Series[str]]], optional
+            filter by PlanningStatus, by default None
+        outage_id : Optional[Union[int, list[int], Series[int]]], optional
+            filter by outageId, by default None
+        outage_vol : Optional[Union[float, list[float], Series[float]]], optional
+            filter by ``OutageVol_MBD = x`` , by default None
+        outage_vol_gt : Optional[float], optional
+            filter by ``OutageVol_MBD > x`` , by default None
+        outage_vol_gte : Optional[float], optional
+            filter by ``OutageVol_MBD >= x`` , by default None
+        outage_vol_lt : Optional[float], optional
+            filter by ``OutageVol_MBD < x`` , by default None
+        outage_vol_lte : Optional[float], optional
+            filter by ``OutageVol_MBD <= x`` , by default None
+        country : Optional[Union[str, list[str], Series[str]]], optional
+            filter by Refinery/Country/Name, by default None
+        region : Optional[Union[str, list[str], Series[str]]], optional
+            filter by Refinery/Region/Name, by default None
+        filter_exp : Optional[str], optional
+            pass-thru ``$filter`` query param to use a handcrafted filter expression, by default None
+        skip : int, optional
+            pass-thru ``$skip`` query param to skip a certain number of records, by default 0
+        page_size : int, optional
+            pass-thru ``pageSize`` query param to request a particular page size, by default 1000
+        paginate : bool, optional
+            whether to auto-paginate the response, by default False
+        raw : bool, optional
+            return a ``requests.Response`` instead of a ``DataFrame, by default False
+
+        Returns
+        -------
+        Union[pd.DataFrame, Response]
+            DataFrame
+              DataFrame of the ``response.json()``
+            Response
+              Raw ``requests.Response`` object
+        Examples
+        --------
+        **Simple**
+        >>> ci.WorldRefineryData().get_outages_grouped(country="United States")
+
+        **Using Lists**
+        >>> ci.WorldRefineryData().get_outages_grouped(process_unit=["Coker", "CDU"])
+
+        """
+        endpoint = "outages"
+
+        filter_params: list[str] = []
+
+        filter_params.append(odata_list_to_filter("start_date", start_date))
+        filter_params.append(odata_list_to_filter("end_date", end_date))
+        filter_params.append(odata_list_to_filter("OutageVol_MBD", outage_vol))
+        filter_params.append(odata_list_to_filter("RefineryId", refinery_id))
+        filter_params.append(odata_list_to_filter("Owner/Name", owner))
+        filter_params.append(odata_list_to_filter("ProcessUnit/Name", process_unit))
+        filter_params.append(odata_list_to_filter("PlanningStatus", planning_status))
+        filter_params.append(odata_list_to_filter("OutageId", outage_id))
+        filter_params.append(odata_list_to_filter("Refinery/Country/Name", country))
+        filter_params.append(odata_list_to_filter("Refinery/Region/Name", region))
+
+        if start_date_gt:
+            filter_params.append(f"start_date gt {start_date_gt}")
+        if start_date_gte:
+            filter_params.append(f"start_date ge {start_date_gte}")
+        if start_date_lt:
+            filter_params.append(f"start_date lt {start_date_lt}")
+        if start_date_lte:
+            filter_params.append(f"start_date le {start_date_lte}")
+
+        if end_date_gt:
+            filter_params.append(f"end_date gt {end_date_gt}")
+        if end_date_gte:
+            filter_params.append(f"end_date ge {end_date_gte}")
+        if end_date_lt:
+            filter_params.append(f"end_date lt {end_date_lt}")
+        if end_date_lte:
+            filter_params.append(f"end_date le {end_date_lte}")
+
+        if outage_vol_gt:
+            filter_params.append(f"OutageVol_MBD gt {outage_vol_gt}")
+        if outage_vol_gte:
+            filter_params.append(f"OutageVol_MBD ge {outage_vol_gte}")
+        if outage_vol_lt:
+            filter_params.append(f"OutageVol_MBD lt {outage_vol_lt}")
+        if outage_vol_lte:
+            filter_params.append(f"OutageVol_MBD le {outage_vol_lte}")
+
+        filter_params = [fp for fp in filter_params if fp != ""]
+
+        if filter_exp is None:
+            filter_exp = " AND ".join(filter_params)
+        elif len(filter_params) > 0:
+            filter_exp = " AND ".join(filter_params) + " AND (" + filter_exp + ")"
+
+        params = {
+            "$skip": skip,
+            "pageSize": page_size,
+            "$count": "true",
+        }
+
+        groupby = "OutageId, RefineryId, Owner/Name, Refinery/Country/Name, Refinery/Region/Name, PlanningStatus, ProcessUnit/Name"
+        aggregate = "OutageVol_MBD with max as OutageVol_MBD, Date with max as end_date, Date with min as start_date"
+        apply_string = f"groupby(({groupby}), aggregate({aggregate}))"
+        params["$apply"] = apply_string
+
+        if filter_exp:
+            params["$filter"] = filter_exp
+
+        # odata endpoint will not allow '+' character in URL seemingly
+        qs = urlencode(params, quote_via=quote)
+
+        return get_data(
+            path=f"{self._endpoint}{endpoint}?{qs}",
+            params={},
+            # params=params,
+            paginate=paginate,
+            raw=raw,
+            df_fn=self._ts_to_df,
+            paginate_fn=self._paginate,
+        )
